@@ -316,7 +316,7 @@ class Status:
         :return: 返回图片中心点坐标元组
         """
         assert self.image_path
-        template_image = ddtank.cv2.imread(self.image_path + '/' + template_image_name)
+        template_image = ddtank.cv2.imread(self.image_path + '/' + template_image_name + '.png')
         x1, y1, x2, y2 = position
         image = self.capture()
         image = ddtank.cv2.cvtColor(image, ddtank.cv2.COLOR_BGR2GRAY)
